document.addEventListener("DOMContentLoaded", (event) => {
	jQuery( document ).ready( function( $ ) {
		$( '.remove-image' ).on( 'click', function( e ) {
			let objectId = $(this).data('id');
			let $inputObject = $('#' + objectId);
			
			$inputObject.val('');
			$('#' + objectId + '-preview .image').html('');
			$(this).hide(0);
		} );
		
		let customUploader;
		$( '.wpsseo-upload-image' ).on( 'click', function( e ) {
			e.preventDefault();

			let objectId = $(this).data('id');
			let inputObject = $('#' + objectId);
			let removeButton = $(this).next();

			if ( customUploader ) {
				customUploader.open();
				return;
			}

			customUploader = wp.media.frames.file_frame = wp.media( {
				title: meta.imageTitle,
				button: {
					text: meta.imageButton
				},
				multiple: false
			} );

			customUploader.on( 'select', function() {
				attachment = customUploader.state().get('selection').first().toJSON();
				attachments = customUploader.state().get('selection').toJSON();

				let imageUrl = attachment.url;

				if (attachment.sizes.medium !== undefined) {
					imageUrl = attachment.sizes.medium.url;
				}
				
				inputObject.val(attachment.id);
				$('#' + objectId + '-preview .image').html('<img src="' + imageUrl + '" alt="">');
				removeButton.show(0);
			} );

			customUploader.open();
		} );

		$( '.color-picker' ).wpColorPicker();
		$( 'select.styled-select, select.select2' ).select2();

		$('[data-toggle-target]').on('change input', function() {
			let $this = $(this);
			let compare = $this.data('toggle-value'),
				target = $this.data('toggle-target'),
				value1 = '', value2 = '';

			if ( compare === '' || compare === undefined ) {
				return;
			}

			if ($this.is('select')) {
				let $selectedOption = $this.find('option:selected'),
					$optgroup = $selectedOption.closest('optgroup');

				if ($optgroup.length) {
					value1 = $optgroup.attr('label');
				}

				value2 = $selectedOption.val();
			} else {
				value1 = $this.val();
			}

			if ( compare === value1 || compare === value2 ) {
				$(target).removeClass('hidden');
			} else {
				$(target).addClass('hidden');
			}
		});

		if ( $('a.wpsseo-button.purge').length > 0 ) {
			$('a.wpsseo-button.purge').on('click', function (e) {
				let $this = $(this);
				e.preventDefault();

				$this.prop('disabled', true);

				let confirmation = $this.data('confirm');
				if (typeof confirmation !== 'undefined') {
					if (!confirm(confirmation)) {
						$this.prop('disabled', false);
						return;
					}
				}

				let input = $this.prev('input');
				let option = input.attr( 'id' );

				$.ajax({
					url: wpsseoAjax.url,
					type: 'POST',
					data: {
						action: 'purgeOption',
						nonce: wpsseoAjax.nonce,
						option: option
					}
				}).done(function (response) {
					if (response.success) {
						window.location.reload();
					} else {
						if (response.data.message) {
							alert(response.data.message);
						}

						$this.prop('disabled', false);
					}
				});
			});
		}

		$('.nav-tab-wrapper.meta a').on( 'click', function(e) {
			e.preventDefault();

			let $this = $(this);
			let target = $this.attr('href');

			$('.nav-tab-wrapper.meta a').removeClass( 'nav-tab-active' );
			$('.tab-content').addClass( 'hidden' );

			$this.addClass( 'nav-tab-active' );
			$( target ).removeClass( 'hidden' ).css('display', 'block');
		} );

		$( '.ai-optimize' ).on( 'click', function( e ) {
			e.preventDefault();
		} );

		function updateTitleCharCounter(title) {
			let titleClass = 'audit1';
			title = title.trim();

			if (title.length < meta.titleMin) {
				titleClass = 'audit2';

				if (title.length < meta.badTitleMin) {
					titleClass = 'audit3';
				}
			}

			if (title.length > meta.titleMax) {
				titleClass = 'audit2';

				if (title.length > meta.badTitleMax) {
					titleClass = 'audit3';
				}
			}

			$('#wpsseo_title_chars').text(title.length).removeAttr('class').addClass(titleClass);
		}

		function updateTitleSerpPreview(title) {
			let previewTitle = title;

			if (title.length > meta.titleMax) {
				previewTitle = title.substring(0, meta.titleMax - 3) + '...';
			}

			if (title.length === 0) {
				previewTitle = meta.emptyTitle;
			}

			$('#wpsseo-serp-preview .title').text(previewTitle);
		}

		function updateDescriptionCharCounter(description) {
			let descriptionClass = 'audit1';
			description = description.trim();

			if (description.length < meta.descriptionMin) {
				descriptionClass = 'audit2';

				if (description.length < meta.badDescriptionMin) {
					descriptionClass = 'audit3';
				}
			}

			if (description.length > meta.descriptionMax) {
				descriptionClass = 'audit2';

				if (description.length > meta.badDescriptionMax) {
					descriptionClass = 'audit3';
				}
			}

			$('#wpsseo_description_chars').text(description.length).removeAttr('class').addClass(descriptionClass);
		}

		function parseAndCleanContent(content) {
			if (typeof wp !== 'undefined' && wp.blocks && typeof wp.blocks.parse === 'function' && content.includes('data-block=')) {
				const blocks = wp.blocks.parse(content);
				let parsedContent = '';
		
				if (typeof wp.blocks.serialize === 'function') {
					blocks.forEach(block => {
						parsedContent += wp.blocks.serialize(block);
					});
				}
		
				return parsedContent || content;
			}

			if (content === meta.blockPlaceholder) {
				return meta.emptyDescription;

			}

			return content;
		}
		
		function removeScriptAndStyleTags(text) {
			const scriptStyleRegex = /<script\b[^<]*(?:(?!<\/script>)<[^<]*)*<\/script>|<style\b[^<]*(?:(?!<\/style>)<[^<]*)*<\/style>/gi;
			return text.replace(scriptStyleRegex, '');
		}
		
		function getCleanDescription(text) {
			let cleanText = parseAndCleanContent(text);
			cleanText = removeScriptAndStyleTags(cleanText);
			return cleanText.trim();
		}

		function stripHtml(html) {
			let doc = new DOMParser().parseFromString(html, 'text/html');
			let textContent = doc.body.textContent || "";
		
			return textContent.replace(/[\r\n]+/g, ' ').replace(/\s+/g, ' ').trim();
		}
		
		function updateDescriptionSerpPreview(description) {
			let previewDescription = stripHtml(getCleanDescription(description));
		
			if (previewDescription.length > meta.descriptionMax) {
				previewDescription = `${previewDescription.substring(0, meta.descriptionMax - 3)}...`;
			} else if (previewDescription.length === 0) {
				previewDescription = meta.emptyDescription;
			}
		
			$('#wpsseo-serp-preview .description').text(previewDescription);
		}
		
		function updateDescriptionPlaceholder(description) {
			$('#wpsseo_description').attr('placeholder', description);
		}

		$( '#wpsseo_title' ).on( 'input change keyup', function() {
			let title = $(this).val();

			if (title.length === 0) {
				title = $(this).attr('placeholder');
			}

			updateTitleCharCounter(title);
			updateTitleSerpPreview(title);
		} );

		$( '#wpsseo_description' ).on( 'input change keyup', function() {
			let description = $(this).val();

			if (description.length === 0) {
				description = $(this).attr('placeholder');
			}

			updateDescriptionCharCounter(description);
			updateDescriptionSerpPreview(description);
		} );

		function getCurrentHeadline(context = 'object', modifiedHeadline = '') {
			let headline = null;
			let headlineText = '';

			if ($('.editor-visual-editor__post-title-wrapper > h1').length > 0) {
				headline = $('.editor-visual-editor__post-title-wrapper > h1').first();
				headlineText = headline.text().trim();
			} else if ($('#swift_theme_headline').length > 0 && $('#swift_theme_headline').val().trim().length > 0) {
				headline = $('#swift_theme_headline');
				headlineText = headline.val().trim();
			} else if ($('#genesis-meta[headline]').length > 0 && $('#genesis-meta[headline]').val().trim().length > 0) {
				headline = $('#genesis-meta[headline]');
				headlineText = headline.val().trim();
			} else if ($('#title').length > 0) {
				headline = $('#title');
				headlineText = headline.val().trim();
			} else if ($('#name').length > 0) {
				headline = $('#name');
				headlineText = headline.val().trim();
			}

			let appendToTitle = false;

			if (headline !== null) {
				if (headlineText.trim().length > 0) {
					if (modifiedHeadline !== '') {
						headlineText = modifiedHeadline;
					}

					let headlineLength = headlineText.trim().length + meta.titleAppend.length;

					if (context !== 'breadcrumb' && headlineLength <= meta.titleMax) {
						appendToTitle = true;
					}
				}
			}

			if (context === 'object') {
				return headline;
			}

			if (context === 'breadcrumb') {
				return headlineText;
			}

			if (headlineText.length === 0) {
				headlineText = meta.emptyTitle;
			}

			if (appendToTitle) {
				return headlineText + meta.titleAppend;
			}

			return headlineText;
		}

		function getCurrentBody(context = 'object') {
			let body = null;
			let bodyText = '';
			let bodyTextStripped = false;

			if ($('.editor-styles-wrapper.block-editor-writing-flow').length > 0) {
				body = $('.editor-styles-wrapper.block-editor-writing-flow .is-root-container').first();
				bodyText = getCleanDescription(body.html());
				bodyTextStripped = true;

				if (bodyText === meta.blockPlaceholder) {
					bodyText = '';
				}
			} else if ($('#swift_theme_intro_text').length > 0) {
				body = $('#swift_theme_intro_text');
				bodyText = body.val().trim();
			} else if ($('.swift_theme_intro_text').length > 0) {
				body = $('.swift_theme_intro_text');
				bodyText = body.val().trim();
			} else if ($('#genesis-meta[description]').length > 0) {
				body = $('#genesis-meta[description]');
				bodyText = body.val().trim();
			} else if ($('#content').length > 0) {
				body = $('#content');
				bodyText = body.val().trim();
			} else if ($('#description').length > 0) {
				body = $('#description');
				bodyText = body.val().trim();
			}

			if (context === 'object') {
				return body;
			}

			if (body !== null) {
				if (!bodyTextStripped){
					bodyText = getCleanDescription(bodyText);
				}
			}

			bodyText = stripHtml(bodyText);

			if (bodyText.length > meta.descriptionMax) {
				bodyText = bodyText.substring(0, meta.descriptionMax - 3).trim() + '...';
			}

			if (bodyText.length === 0) {
				bodyText = meta.emptyDescription;
			}

			return bodyText;
		}

		function updateDescriptionsOnInput(bodyText) {
			if (bodyText.length > 0) {
				if (bodyText !== meta.blockPlaceholder) {
					updateDescriptionPlaceholder(bodyText);
				}
			} else {
				updateDescriptionPlaceholder(meta.empty_description);
			}

			if ($('#wpsseo_description').val().length === 0) {
				updateDescriptionSerpPreview(bodyText);

				if (bodyText !== meta.empty_description) {
					updateDescriptionCharCounter(bodyText);
				} else {
					updateDescriptionCharCounter('');
				}
			}
		}

		setTimeout( function () {
			let currentHeadlineElement = getCurrentHeadline();
			let headlineText = getCurrentHeadline('text');
			let breadcrumbText = getCurrentHeadline('breadcrumb');

			if (typeof wpsgls !== 'undefined' && wpsgls.titlePlaceholder !== undefined) {
				headlineText = getCurrentHeadline('text', wpsgls.titlePlaceholder.replace('[term]', breadcrumbText));
			}

			if (currentHeadlineElement !== null && $('#wpsseo_title').length > 0) {
				if (headlineText.length > 0) {
					$('#wpsseo_title').attr('placeholder', headlineText);
					$('#wpsseo_breadcrumb_title').attr('placeholder', breadcrumbText);

					if ($('#wpsseo_title').val().length === 0) {
						updateTitleSerpPreview(headlineText);

						if (headlineText !== meta.empty_title) {
							updateTitleCharCounter(headlineText);
						} else {
							updateTitleCharCounter('');
						}
					}
				}

				function attachDynamicEventListener(element) {
					element.on('input change keyup', function () {
						let newHeadlineElement = getCurrentHeadline();
						if (!currentHeadlineElement.is(newHeadlineElement)) {
							currentHeadlineElement = newHeadlineElement;

							if (currentHeadlineElement) {
								attachDynamicEventListener(currentHeadlineElement);
							}
						}

						let headlineText = getCurrentHeadline('text');
						let breadcrumbText = getCurrentHeadline('breadcrumb');

						if (typeof wpsgls !== 'undefined' && wpsgls.titlePlaceholder !== undefined) {
							headlineText = getCurrentHeadline('text', wpsgls.titlePlaceholder.replace('[term]', breadcrumbText));
						}

						$('#wpsseo_title').attr('placeholder', headlineText);
						$('#wpsseo_breadcrumb_title').attr('placeholder', breadcrumbText);

						if ($('#wpsseo_title').val().length === 0) {
							updateTitleSerpPreview(headlineText);

							if (headlineText !== meta.empty_title) {
								updateTitleCharCounter(headlineText);
							} else {
								updateTitleCharCounter('');
							}
						}
					});
				}

				attachDynamicEventListener(currentHeadlineElement);
			}

			let body = getCurrentBody();
			let bodyText = getCurrentBody('text');

			if (body !== null && $('#wpsseo_description').length > 0) {
				if (bodyText.length > 0) {
					if (bodyText !== meta.blockPlaceholder) {
						updateDescriptionPlaceholder(bodyText);
					}

					if ($('#wpsseo_description').val().length === 0) {
						updateDescriptionSerpPreview(bodyText);

						if (bodyText !== meta.empty_description) {
							updateDescriptionCharCounter(bodyText);
						} else {
							updateDescriptionCharCounter('');
						}
					}
				}

				body.on('input change keyup', function () {
					bodyText = getCurrentBody('text');

					updateDescriptionsOnInput(bodyText);
				});

				setTimeout( function () {
					let eBodyText1 = '';
					let eBodyText2 = '';
					
					let editor = tinymce.get('swift_theme_intro_text');
					if (editor) {
						editor.on('input change keyup', function(e) {
							if (typeof e.currentTarget !== 'undefined') {
								eBodyText1 = stripHtml(e.currentTarget.innerText);
								bodyText = eBodyText1 + ' ' + eBodyText2;

								if (bodyText.length > meta.descriptionMax) {
									bodyText = bodyText.substring(0, meta.descriptionMax - 3).trim() + '...';
								}

								updateDescriptionsOnInput(bodyText.trim());
							}
						});
					}
					
					let editor2 = tinymce.get('swift_theme_additional_intro_text');
					if (editor2) {
						editor2.on('input change keyup', function(e) {
							if (typeof e.currentTarget !== 'undefined') {
								eBodyText2 = stripHtml(e.currentTarget.innerText);
								bodyText = eBodyText1 + ' ' + eBodyText2;

								if (bodyText.length > meta.descriptionMax) {
									bodyText = bodyText.substring(0, meta.descriptionMax - 3).trim() + '...';
								}

								updateDescriptionsOnInput(bodyText.trim());
							}
						});
					}
				}, 100 );
			}
		}, 100 );

		(function($, wp) {
			// Function to handle updating the primary category select options
			function updatePrimaryCategorySelect(primaryCategorySelect, currentCategories, defaultCategoryId) {
				let options = primaryCategorySelect.querySelectorAll('option');
				let hasSelectedCategories = currentCategories.length > 0;
		
				options.forEach(option => {
					let categoryId = parseInt(option.value);
					let isDefaultCategory = categoryId === parseInt(defaultCategoryId);
		
					if (hasSelectedCategories) {
						// If category is selected, enable it if it is in the current categories
						if (currentCategories.includes(categoryId)) {
							option.disabled = false;
						} else {
							option.disabled = true;
						}
					} else {
						// If no category is selected, enable all categories except the default category
						option.disabled = !isDefaultCategory;
						if (isDefaultCategory) {
							primaryCategorySelect.value = defaultCategoryId; // Set default category as selected
						}
					}
				});
		
				// If the selected category is disabled, select the first enabled category
				let selectedOption = primaryCategorySelect.selectedOptions[0];
				if (selectedOption.disabled) {
					let firstEnabledOption = primaryCategorySelect.querySelector('option:not([disabled])');
					if (firstEnabledOption) {
						primaryCategorySelect.value = firstEnabledOption.value;
					} else {
						primaryCategorySelect.value = defaultCategoryId;
					}
				}
			}
		
			// Handle checkbox click events
			$('.categorydiv').on('click', 'input[type=checkbox]', function() {
				let primaryCategorySelect = document.querySelector('#primary_category');
				let defaultCategoryId = primaryCategorySelect.getAttribute('data-default');
		
				if (!primaryCategorySelect) {
					return;
				}
		
				// Get the current categories
				let currentCategories = $('.categorydiv input[type=checkbox]:checked').map(function() {
					return parseInt($(this).val());
				}).get();
		
				updatePrimaryCategorySelect(primaryCategorySelect, currentCategories, defaultCategoryId);
			});
		
			// WordPress data subscription for category changes
			if (wp && wp.data) {
				let subscribe = wp.data.subscribe;
				let select = wp.data.select;
				let core = select('core/editor');

				if (core === undefined) {
					return;
				}
		
				let primaryCategorySelect = document.querySelector('#primary_category');
				if (!primaryCategorySelect) {
					return;
				}
		
				let defaultCategoryId = primaryCategorySelect.getAttribute('data-default');
		
				subscribe(function () {
					let currentCategoryIds = core.getEditedPostAttribute('categories') || [];
					let allCategories = select('core').getEntityRecords('taxonomy', 'category');

					if (allCategories) {
						allCategories.forEach(category => {
							if ($('#primary_category').find('option[value="' + category.id + '"]').length === 0) {
								$('#primary_category').append(new Option(category.name, category.id));
							}
						});
					}

					updatePrimaryCategorySelect(primaryCategorySelect, currentCategoryIds, defaultCategoryId);
				});
			}
		})(jQuery, window.wp);
	} );
} );