<?php

if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly
}

class SwiftAdminColumns
{
	public function __construct()
	{
		if (!is_admin()) {
			return;
		}

		$enableProPreview = (bool) get_option('wpsseo_enable_pro_preview', true);
		if (!$enableProPreview) {
			return;
		}

		add_action('admin_init', [$this, 'initColumns'], 1);
	}

	public static function init()
	{
		return new self();
	}

	public function initColumns()
	{
		$postTypes = array_keys(SwiftPostTypes::getPostTypes());
		foreach ($postTypes as $postType) {
			add_filter("manage_{$postType}_posts_columns", [$this, 'addColumns']);
			add_action("manage_{$postType}_posts_custom_column", [$this, 'displayPostColumns'], 10, 2);
		}

		$taxonomies = array_keys(SwiftTaxonomies::getTaxonomies());
		foreach ($taxonomies as $taxonomy) {
			add_filter("manage_edit-{$taxonomy}_columns", [$this, 'addColumns']);
			add_action("manage_{$taxonomy}_custom_column", [$this, 'displayTaxonomyColumns'], 10, 3);
		}

		add_filter('manage_users_columns', [$this, 'addColumns']);
		add_filter('manage_users_custom_column', [$this, 'displayAuthorColumns'], 10, 3);
	}

	public function addColumns($columns)
	{
		$columns['seo-health'] = __('SEO Health', WPSSEO_TEXT_DOMAIN);

		return $columns;
	}

	public function displayPostColumns($column, $termId)
	{
		echo $this->getColumnsData($termId, 'post', $column);
	}

	public function displayTaxonomyColumns($returnString, $column, $termId)
	{
		$columnData = $this->getColumnsData($termId, 'term', $column);
		if (!empty($columnData)) {
			$returnString = $columnData;
		}

		return $returnString;
	}

	public function displayAuthorColumns($returnString, $column, $userId)
	{
		$columnData = $this->getColumnsData($userId, 'author', $column);
		if (!empty($columnData)) {
			$returnString = $columnData;
		}

		return $columnData ?: $returnString;
	}

	private function getColumnsData($objectId, $type, $column)
	{
		if ($column !== 'seo-health') {
			return null;
		}

		$indicator = '<span class="wpsseo-indicator audit0"></span>';
		$title = __('SEO health is only available in the pro version of Swift SEO.', WPSSEO_TEXT_DOMAIN);
		$text = __('Only in Pro', WPSSEO_TEXT_DOMAIN);

		return '<span title="' . $title . '" style="cursor: help">' . $indicator . $text . '</span>';
	}
}
