<?php

if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly
}

class SwiftSeoHealth
{
	protected $options;

	public function __construct()
	{
		if (!is_admin()) {
			return;
		}

		$enableProPreview = (bool) get_option('wpsseo_enable_pro_preview', true);
		if (!$enableProPreview) {
			return;
		}

		add_action('admin_menu', [$this, 'addAnalysisPages'], 99);
		add_action('admin_menu', [$this, 'addLogPages'], 99);
	}

	public static function init()
	{
		return new self();
	}

	public function addAnalysisPages()
	{
		add_menu_page(
			esc_html__('SEO Health', WPSSEO_TEXT_DOMAIN), // Document Title - Not used when callback is null
			esc_html__('SEO Health', WPSSEO_TEXT_DOMAIN), // Menu Title
			'edit_posts', // Capability
			'swift-seo-health', // Menu Slug
			[$this, 'addAnalysisTable'], // Callback
			'dashicons-analytics', // Icon
			98 // Position
		);
	}

	public function addLogPages()
	{
		add_submenu_page(
			'swift-seo-health', // Parent Slug
			esc_html__('Swift SEO Logs', WPSSEO_TEXT_DOMAIN), // Document Title - Not used when callback is null
			esc_html__('Logs', WPSSEO_TEXT_DOMAIN), // Menu Title
			'manage_options', // Capability
			'swift-seo-logs', // Menu Slug
			[$this, 'addLogsPage'] // Callback
		);
	}

	public function addAnalysisTable()
	{
		echo '<div class="wrap">
			<h1>' . __('Global SEO Health Analysis', WPSSEO_TEXT_DOMAIN) . '</h1>';

		$this->addTabs();

		echo '<div class="pro-preview preview-seo-health">
			' . sprintf(__('%sSEO Health Analysis is a Pro feature.%s%sGet Swift SEO Pro%s', WPSSEO_TEXT_DOMAIN), '<p>', '</p>', '<a href="' . WPSSEO_PLUGIN_URI . '" target="_blank" class="wpsseo-button hero">', '</a>') . '
		</div>';

		echo '</div>';
	}

	private function getTabs()
	{
		$currentTab = filter_input(INPUT_GET, 'tab');

		$postTypes = SwiftPostTypes::getPostTypes();
		$taxonomies = SwiftTaxonomies::getTaxonomies();

		$allTabs = [];
		$i = 1;

		$noindexPostTypes = get_option('wpsseo_noindex_post_types');
		foreach ($postTypes as $postType => $label) {
			if (!empty($noindexPostTypes) && in_array($postType, array_keys($noindexPostTypes))) {
				continue;
			}

			$postIds = SwiftPostTypes::getPostTypeIds($postType);
			if (empty($postIds)) {
				continue;
			}
			
			$allTabs[] = [
				'key' => $postType,
				'type' => 'post',
				'label' => $label,
				'active' => (bool) ($currentTab === $postType || (empty($currentTab) && $i === 1) ? true : false),
			];

			++$i;
		}

		$noindexTaxonomies = get_option('wpsseo_noindex_taxonomies');
		foreach ($taxonomies as $taxonomy => $label) {
			if (!empty($noindexTaxonomies) && in_array($taxonomy, array_keys($noindexTaxonomies))) {
				continue;
			}

			$termIds = SwiftTaxonomies::getTermIds($taxonomy);
			foreach ($termIds as $termKey => $termId) {
				if (!SwiftTaxonomies::termHasPosts($termId, $taxonomy)) {
					unset($termIds[$termKey]);
				}
			}

			if (empty($termIds)) {
				continue;
			}

			$allTabs[] = [
				'key' => $taxonomy,
				'type' => 'term',
				'label' => $label,
				'active' => (bool) ($currentTab === $taxonomy || (empty($currentTab) && $i === 1) ? true : false),
			];

			++$i;
		}

		$noindexArchives = get_option('wpsseo_noindex_archives');
		if (!empty($noindexArchives) && in_array('author', array_keys($noindexArchives))) {
			return $allTabs;
		}

		$authorIds = SwiftAuthor::getAuthorIds();
		if (empty($authorIds)) {
			return $allTabs;
		}

		$allTabs[] = [
			'key' => 'author',
			'type' => 'author',
			'label' => __('Users', WPSSEO_TEXT_DOMAIN),
			'active' => (bool) ($currentTab === 'author' || (empty($currentTab) && $i === 1) ? true : false),
		];

		return $allTabs;
	}

	private function addTabs()
	{
		$page = filter_input(INPUT_GET, 'page');
		$allTabs = $this->getTabs();

		echo '<h2 class="nav-tab-wrapper wpsseo-tabs">';

		$i = 1;

		foreach ($allTabs as $tab) {
			$tabKey = $tab['key'];
			$type = $tab['type'];
			$label = $tab['label'];
			$currentTabActive = (bool) $tab['active'];

			echo '<a href="' . admin_url("/admin.php?page={$page}&tab={$tabKey}&type={$type}") . '" class="nav-tab' . ($currentTabActive ? ' nav-tab-active' : '') . '">' . $label . '</a>';

			++$i;
		}

		echo '</h2>' . "\n";
	}

	public function addLogsPage()
	{
		echo '<div class="wrap">
			<h1>' . __('Swift SEO Logs', WPSSEO_TEXT_DOMAIN) . '</h1>';

		echo '<div class="pro-preview preview-logs">
			' . sprintf(__('%sLog access is a Pro feature.%s%sGet Swift SEO Pro%s', WPSSEO_TEXT_DOMAIN), '<p>', '</p>', '<a href="' . WPSSEO_PLUGIN_URI . '" target="_blank" class="wpsseo-button hero">', '</a>') . '
		</div>';

		echo '</div>';
	}
}
