<?php

if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly
}

class SwiftRemoveGenesisSeo
{
	public function __construct()
	{
		// Remove Genesis SEO settings option page
		add_action('after_setup_theme', [$this, 'removeSeoSettingsMenu']);

		add_action('init', [$this, 'removePostElements']);
		add_action('init', [$this, 'disableSchemaAttr']);
		add_action('init', [$this, 'removeAuthorMeta'], 100);
		add_action('enqueue_block_editor_assets', [$this, 'removeMetaboxes'], 99);

		remove_action('genesis_before', 'genesis_page_specific_body_scripts', 99);
		add_filter('genesis_detect_seo_plugins', [$this, 'detectSwiftSeo']);
		add_filter('admin_body_class', [$this, 'addBodyClass']);
		add_action('genesis_init', [$this, 'unhookFeedTitleMod'], 15);
	}

	public function unhookFeedTitleMod()
	{
		if (SwiftUtilities::isFeed()) {
			remove_filter('document_title_parts', 'genesis_document_title_parts');
		}
	}

	public static function init()
	{
		if (defined('GENESIS_LOADED_FRAMEWORK')) {
			return;
		}

		return new self();
	}

	public function detectSwiftSeo($disabled)
	{
		$disabled['constants'][] = 'WPSSEO_VERSION';

		return $disabled;
	}

	public function addBodyClass($classes)
	{
		if (defined('GENESIS_LOADED_FRAMEWORK')) {
			$classes .= ' wpsseo-genesis ';
		}

		return $classes;
	}

	public function removePostElements()
	{
		remove_action('wp_head', 'genesis_canonical', 5);
		remove_action('wp_head', 'genesis_header_scripts');
		remove_action('genesis_before', 'genesis_page_specific_body_scripts');
		remove_action('wp_footer', 'genesis_footer_scripts');

		if (!is_admin()) {
			return;
		}

		$builtinPostTypes = ['post', 'page'];
		$customPostTypes = get_post_types(['_builtin' => false]);
		$allPostTypes = array_merge($builtinPostTypes, array_values($customPostTypes));

		foreach ($allPostTypes as $postType) {
			remove_post_type_support($postType, 'genesis-scripts');
		}
	}

	public function disableSchemaAttr()
	{
		// Update from Genesis Framework: /lib/functions/schema.php
		$disable = [
			'head',
			'body',
			'site-header',
			'site-title',
			'site-description',
			'breadcrumb',
			'breadcrumb-link-wrap',
			'breadcrumb-link-wrap-meta',
			'breadcrumb-link',
			'breadcrumb-link-text-wrap',
			'search-form',
			'search-form-meta',
			'search-form-input',
			'nav-primary',
			'nav-secondary',
			'nav-header',
			'nav-link-wrap',
			'nav-link',
			'entry',
			'entry-image',
			'singular-entry-image',
			'entry-image-widget',
			'entry-image-grid-loop',
			'entry-author',
			'entry-author-link',
			'entry-author-name',
			'entry-time',
			'entry-modified-time',
			'entry-title',
			'entry-content',
			'comment',
			'comment-author',
			'comment-author-link',
			'comment-author-name',
			'comment-time',
			'comment-time-link',
			'comment-content',
			'author-box',
			'sidebar-primary',
			'sidebar-secondary',
			'site-footer',
		];

		foreach ($disable as $element) {
			add_filter('genesis_attr_' . $element, [$this, 'removeSchemaAttributes'], 20);
		}
	}

	public function removeSchemaAttributes($attr)
	{
		unset($attr['itemprop'], $attr['itemtype'], $attr['itemscope']);

		return $attr;
	}

	public function removeAuthorMeta()
	{
		remove_action('show_user_profile', 'genesis_user_seo_fields');
		remove_action('edit_user_profile', 'genesis_user_seo_fields');
	}

	public function removeMetaboxes()
	{
		wp_dequeue_script('genesis-breadcrumbs-toggle');
		wp_deregister_script('genesis-breadcrumbs-toggle');
	}

	public function removeSeoSettingsMenu()
	{
		remove_theme_support('genesis-seo-settings-menu');
	}
}
