<?php

if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly
}

class SwiftAuthor
{
	public static $socialProfileOptions = [
		'wpsseo_facebook' => 'Facebook URL',
		'wpsseo_linkedin' => 'Linkedin URL',
		'wpsseo_youtube' => 'Youtube URL',
		'wpsseo_twitter' => 'Twitter URL',
		'wpsseo_github' => 'Github URL',
		'wpsseo_stackoverflow' => 'Stack Overflow URL',
		'wpsseo_skype' => 'Skype URL',
		'wpsseo_snapchat' => 'Snapchat URL',
		'wpsseo_twitch' => 'Twitch URL',
		'wpsseo_steam' => 'Steam URL',
		'wpsseo_pinterest' => 'Pinterest URL',
		'wpsseo_vimeo' => 'Vimeo URL',
		'wpsseo_instagram' => 'Instagram URL',
	];

	public function __construct()
	{
		add_action('wpsseo_meta_tags', [$this, 'addAuthorMetaTag']);
		add_action('user_contactmethods', [$this, 'addSocialProfiles']);

		add_action('show_user_profile', [$this, 'renderMetabox']);
		add_action('edit_user_profile', [$this, 'renderMetabox']);

		add_action('profile_update', [$this, 'saveMetabox']);
	}

	public static function init()
	{
		return new self();
	}

	public static function getAuthorIds()
	{
		$authorIds = get_users([
			'role__in' => ['administrator', 'editor', 'author'],
			'fields' => 'ids',
			'meta_query' => [
				'relation' => 'OR',
				[
					'key' => 'noindex',
					'value' => 1,
					'compare' => '!=',
					'type' => 'NUMERIC',
				],
				[
					'key' => 'noindex',
					'compare' => 'NOT EXISTS',
				]
			],
		]);

		return $authorIds;
	}

	public function renderMetabox($user)
	{
		if (empty($user->ID)) {
			return;
		}

		echo '<div class="postbox wpsseo wpsseo-settings"><div class="inside"><h2>' . __('Search Engine Optimization - Swift SEO', WPSSEO_TEXT_DOMAIN) . '</h2>';
		echo SwiftMetaBoxes::seoMetabox($user, 'author');
		echo '</div></div>';
	}

	public function saveMetabox(int $userId)
	{
		if (!isset($_POST['save_seo_meta']) || !wp_verify_nonce(wp_unslash($_POST['save_seo_meta']), 'save_seo_meta')) {
			return;
		}

		$user = get_user_by('ID', $userId);
		$autoTitle = sanitize_text_field(SwiftContent::generateDocumentTitle($user, 'author'));
		$autoDescription = sanitize_text_field(SwiftContent::generateMetaDescription($user, 'author'));
		$metaTitle = sanitize_text_field($_POST['wpsseo_title']);
		$metaDescription = sanitize_textarea_field($_POST['wpsseo_description']);
		$canonical = sanitize_text_field($_POST['wpsseo_canonical']);
		$primaryKeyword = sanitize_text_field($_POST['wpsseo_primary_keyword']);
		$secondaryKeywords = sanitize_text_field($_POST['wpsseo_secondary_keywords']);
		$socialImageId = intval($_POST['wpsseo_social_image'] ?? 0);
		$noindex = isset($_POST['wpsseo_noindex']) && !empty($_POST['wpsseo_noindex']) ? true : false;
		$nofollow = isset($_POST['wpsseo_nofollow']) && !empty($_POST['wpsseo_nofollow']) ? true : false;
		$metaTagsCache = isset($_POST['wpsseo_meta_tags_cache']) && !empty($_POST['wpsseo_meta_tags_cache']) ? 1 : 0;
		$breadcrumbTitle = sanitize_text_field($_POST['wpsseo_breadcrumb_title']);
		$headerScripts = sanitize_text_field($_POST['wpsseo_header_scripts']);
		$bodyScripts = sanitize_text_field($_POST['wpsseo_body_scripts']);

		update_user_meta($userId, '_auto_title', $autoTitle);
		update_user_meta($userId, '_auto_description', $autoDescription);
		update_user_meta($userId, 'doctitle', $metaTitle);
		update_user_meta($userId, 'meta_description', $metaDescription);
		update_user_meta($userId, '_genesis_canonical_uri', $canonical);
		update_user_meta($userId, 'noindex', $noindex);
		update_user_meta($userId, 'nofollow', $nofollow);
		update_user_meta($userId, '_meta_tags_cache', $metaTagsCache);
		update_user_meta($userId, '_primary_keyword', $primaryKeyword);
		update_user_meta($userId, '_secondary_keywords', $secondaryKeywords);
		update_user_meta($userId, '_social_image_id', $socialImageId);
		update_user_meta($userId, '_breadcrumb_title', $breadcrumbTitle);
		update_user_meta($userId, '_genesis_scripts', $headerScripts);
		update_user_meta($userId, '_genesis_scripts_body', $bodyScripts);

		delete_transient("wpsseo_meta_tags_author_{$userId}");

		global $wpdb;
		$wpdb->query($wpdb->prepare("DELETE FROM `{$wpdb->prefix}options` WHERE `option_name` LIKE %s", "_transient%_wpsseo_sitemap_author%"));
	}

	public function addAuthorMetaTag($metaTags)
	{
		$authorName = '';

		if (is_singular(array_keys(SwiftPostTypes::getPostTypes()))) {
			$post = get_post();

			if (!empty($post->post_author)) {
				$author = get_user_by('ID', $post->post_author);

				if (!empty($author)) {
					$authorName = $author->display_name;
				}
			}

			if (empty($authorName)) {
				$authorArray = get_users([
					'role' => 'administrator',
					'fields' => ['display_name'],
					'number' => 1,
				]);

				if (empty($authorArray)) {
					return $metaTags;
				}

				$author = reset($authorArray);
				$authorName = $author->display_name;
			}
		}

		if (!empty($authorName)) {
			$metaTags .= '<meta name="author" content="' . $authorName . '">' . "\n";
		}

		return $metaTags;
	}

	public function addSocialProfiles($methods)
	{
		return array_merge($methods, self::$socialProfileOptions);
	}

	public static function getSocialProfiles($userId = null)
	{
		if (empty($userId)) {
			if (!is_author()) {
				return [];
			}

			$userId = get_the_author_meta('ID');
		}

		$socialMeta = [];

		foreach (self::$socialProfileOptions as $key => $label) {
			$value = get_user_meta($userId, $key, true);

			if (!empty($value)) {
				$socialMeta[$key] = $value;
			}
		}

		return $socialMeta;
	}
}
