<?php

if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly
}

class SwiftImages
{
	public function __construct()
	{
		add_action('init', [$this, 'addCustomImageSizes']);
		add_action('add_attachment', [$this, 'autoAltTextOnUpload']);
		add_filter('sanitize_file_name', [$this, 'sanitizeFilename'], 10);
	}

	public static function init()
	{
		return new self();
	}

	public function addCustomImageSizes()
	{
		add_image_size('social-image', 1200, 630, true);
	}

	public function autoAltTextOnUpload($post_id)
	{
		if (!wp_attachment_is_image($post_id)) {
			return;
		}

		$attachment = get_post($post_id);
		$image_title = preg_replace('%\s*[-_\s]+\s*%', ' ', $attachment->post_title);
		$image_alt_text = ucwords(mb_strtolower(trim($image_title)));

		update_post_meta($post_id, '_wp_attachment_image_alt', $image_alt_text);
	}

	public function sanitizeFilename($filename)
	{
		$pathinfo = pathinfo($filename);

		if (empty($pathinfo['extension'])) {
			return $filename;
		}

		$name = sanitize_file_name($pathinfo['filename']);
		$ext = $pathinfo['extension'];

		if (strlen($name) > 59) {
			$name = substr($name, 0, 59);
		}

		return "{$name}.{$ext}";
	}
}
