<?php

if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly
}

class SwiftPostTypes
{
	public static function woocommerceIds()
	{
		$woocommerceIds = [];
		$woocommercePages = [
			'woocommerce_cart_page_id',
			'woocommerce_checkout_page_id',
			'woocommerce_pay_page_id',
			'woocommerce_thanks_page_id',
			'woocommerce_myaccount_page_id',
			'woocommerce_edit_address_page_id',
			'woocommerce_view_order_page_id',
			'woocommerce_terms_page_id',
			'woocommerce_refund_returns_page_id',
		];

		foreach ($woocommercePages as $optionName) {
			$pageId = get_option($optionName, 0);

			if (!empty($pageId)) {
				$woocommerceIds[] = $pageId;
			}
		}

		return $woocommerceIds;
	}

	public static function getPostTypes()
	{
		$postTypesInitial = get_post_types(['public' => true], 'objects');
		$postTypes = [];

		unset($postTypesInitial['e-floating-buttons']);
		unset($postTypesInitial['elementor_library']);

		foreach ($postTypesInitial as $postType) {
			$postTypes[$postType->name] = $postType->label;
		}

		return $postTypes;
	}

	public static function getPostTypeIds($postType = 'post')
	{
		global $wpdb;

		$postTypeIds = $wpdb->get_col(
			$wpdb->prepare(
				"SELECT `ID` FROM `{$wpdb->posts}`
				WHERE `post_type` = %s
				AND `post_status` = 'publish'
				AND `ID` NOT IN (
					SELECT `post_id` FROM `{$wpdb->postmeta}`
					WHERE `meta_key` = '_genesis_noindex'
					AND `meta_value` = 1
				)",
				$postType
			)
		);

		$woocommerceIds = self::woocommerceIds();
		if (!empty($woocommerceIds)) {
			$postTypeIds = array_diff($postTypeIds, $woocommerceIds);
		}

		return $postTypeIds;
	}
}
