<?php

if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly
}

class SwiftPingService
{
	public function __construct()
	{
		register_activation_hook(WPSSEO_FILE, [$this, 'pingSites']);
		add_action('wp_after_insert_post', [$this, 'notifySearchEngines'], 10, 2);
	}

	public static function init()
	{
		return new self();
	}

	public function pingSites()
	{
		$pingSites = 'http://rpc.pingomatic.com
https://rpc.twingly.com/
https://blogmatcher.com/u.php
https://ping.feedburner.com
https://www.blogdigger.com/RPC2
http://pingoat.com/goat/RPC2
http://blo.gs/ping.php';

		update_option('ping_sites', $pingSites);
	}

	public function notifySearchEngines($postId, $post)
	{
		if (!WPSSEO_IS_PUBLIC || (defined('WP_ENVIRONMENT_TYPE') && WP_ENVIRONMENT_TYPE !== 'production')) {
			return;
		}

		if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
			return;
		}

		if (wp_is_post_revision($postId)) {
			return;
		}

		if ($post->post_status !== 'publish') {
			return;
		}

		$allowedPostTypes = SwiftPostTypes::getPostTypes();
		if (!in_array($post->post_type, array_keys($allowedPostTypes))) {
			return;
		}

		$noindexPost = (bool) get_post_meta($postId, '_genesis_noindex', true);
		$noindexPostTypes = get_option('wpsseo_noindex_post_types');
		if ($noindexPost || (!empty($noindexPostTypes) && in_array($post->post_type, array_keys($noindexPostTypes)))) {
			return;
		}

		$now = time();
		$lastIndexnowRequest = (int) get_post_meta($postId, 'last_indexnow_request', true);
		if (!empty($lastIndexnowRequest)) {
			if ($now - $lastIndexnowRequest < 600) {
				return;
			}
		}

		$indexnowApiKey = get_option('wpsseo_indexnow_api_key');
		$serverRoot = SwiftSettings::getServerRoot();
		$indexnowVerificationFile = "{$serverRoot}/{$indexnowApiKey}.txt";

		if (!file_exists($indexnowVerificationFile)) {
			return;
		}

		$postUrl = urlencode(get_permalink($postId));
		// Search Engine List: https://www.indexnow.org/faq
		$searchEngines = [
			'https://api.indexnow.org/indexnow',
			'https://www.bing.com/indexnow',
			'https://searchadvisor.naver.com/indexnow',
			'https://search.seznam.cz/indexnow',
			'https://yandex.com/indexnow',
			'https://indexnow.yep.com/indexnow',
		];

		foreach ($searchEngines as $searchEngine) {
			$searchEngineUrl = "{$searchEngine}?url={$postUrl}&key={$indexnowApiKey}";

			@get_headers($searchEngineUrl);
		}

		update_post_meta($postId, 'last_indexnow_request', $now);
	}
}
