<?php

if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly
}

class SwiftRobots
{
	public function __construct()
	{
		if (is_admin()) {
			return;
		}

		add_filter('robots_txt', [$this, 'modifyRobotsTxt'], 11);
		add_filter('pre_get_posts', [$this, 'filterSearch']);
	}

	public static function init()
	{
		return new self();
	}

	public function modifyRobotsTxt($output)
	{
		if (!WPSSEO_IS_PUBLIC) {
			return "User-agent: *\nDisallow: /";
		}

		$allowPdfIndex = (bool) get_option('wpsseo_allow_pdf_indexing', false);
		$removeFeeds = get_option('wpsseo_remove_rss_feeds', false);

		if (strpos($output, 'User-agent: *') === false) {
			$output = "User-agent: *\n";
			$output .= "Disallow: /wp-admin/\n";
			$output .= "Allow: /wp-admin/admin-ajax.php\n";
		}

		if (!$allowPdfIndex) {
			$output .= "Disallow: *.pdf\n";
		}

		if ($removeFeeds) {
			$output .= "Disallow: */feed/\n";
		}

		$output .= "Disallow: /wp-json/\n";

		// Cloudflare Challenges
		$output .= "Disallow: /cdn-cgi/bm/cv/\n";
		$output .= "Disallow: /cdn-cgi/challenge-platform/\n";

		// Cloudflare email protection
		$output .= "Disallow: /cdn-cgi/l/email-protection/\n\n";

		// Block harmful bots
		$output .= "User-agent: Nuclei\n";
		$output .= "User-agent: WikiDo\n";
		$output .= "User-agent: Riddler\n";
		$output .= "User-agent: PetalBot\n";
		$output .= "User-agent: Zoominfobot\n";
		$output .= "User-agent: Go-http-client\n";
		$output .= "User-agent: Node/simplecrawler\n";
		$output .= "User-agent: CazoodleBot\n";
		$output .= "User-agent: dotbot/1.0\n";
		$output .= "User-agent: Gigabot\n";
		$output .= "User-agent: Barkrowler\n";
		$output .= "User-agent: BLEXBot\n";
		$output .= "User-agent: magpie-crawler\n";
		$output .= "Disallow: /\n";

		// Add sitemap
		$sitemapUrl = home_url(SwiftSitemap::getSitemapName());
		$output .= "\nSitemap: $sitemapUrl\n";

		return $output;
	}

	public function filterSearch($query)
	{
		if (!$query->is_search) {
			return $query;
		}

		$excludeNoindex = (bool) get_option('wpsseo_exclude_noindex_from_search');

		if ($excludeNoindex) {
			global $wpdb;

			$meta_key = '_genesis_noindex';
			$meta_value = '1';

			$sql = $wpdb->prepare("
				SELECT pm.post_id
				FROM {$wpdb->postmeta} pm
				WHERE pm.meta_key = %s
				AND pm.meta_value = %s
			", $meta_key, $meta_value);

			$exclude = $wpdb->get_col($sql);
			$exclude = !empty($exclude) ? array_map('intval', $exclude) : [];

			$query->set('post__not_in', $exclude);
		}

		return $query;
	}
}
