<?php

if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly
}

class SwiftRedirects
{
	public $postTypes;

	public function __construct()
	{
		add_action('template_redirect', [$this, 'redirectToLowercase'], 20);

		$enableProPreview = (bool) get_option('wpsseo_enable_pro_preview', true);
		if (!$enableProPreview) {
			return;
		}

		add_action('admin_menu', [$this, 'addRedirectMenus']);
	}

	public static function init()
	{
		return new self();
	}

	public function addRedirectMenus()
	{
		add_menu_page(__('Swift Redirect Manager', WPSSEO_TEXT_DOMAIN), __('Swift Redirects', WPSSEO_TEXT_DOMAIN), 'manage_options', 'wpsseo-redirects', [$this, 'renderRedirectPage'], 'dashicons-randomize', 97);
		add_submenu_page('wpsseo-redirects', __('404 errors', WPSSEO_TEXT_DOMAIN), __('404 errors', WPSSEO_TEXT_DOMAIN), 'manage_options', 'wpsseo-redirects-404', [$this, 'renderRedirectPage']);
		add_submenu_page('wpsseo-redirects', __('Redirect Settings', WPSSEO_TEXT_DOMAIN), __('Settings', WPSSEO_TEXT_DOMAIN), 'manage_options', 'wpsseo-redirects-settings', [$this, 'renderRedirectPage']);
	}

	public function renderRedirectPage(): void
	{
		echo '<div class="wrap">
			<h1>' . __('Swift SEO - Redirect Manager', WPSSEO_TEXT_DOMAIN) . '</h1>';

		$this->addTabs();

		echo '<div class="tab-content">';

		$this->renderPreviewBox();

		echo '</div></div>';
	}

	public function render404Page(): void
	{
		echo '<div class="wrap">
			<h1>' . __('Swift SEO - 404 Manager', WPSSEO_TEXT_DOMAIN) . '</h1>';

		$this->addTabs();

		echo '<div class="tab-content">';

		$this->renderPreviewBox();

		echo '</div></div>';
	}

	public function renderRedirectSettings(): void
	{
		echo '<div class="wrap">
			<h1>' . __('Swift SEO - Redirect Settings', WPSSEO_TEXT_DOMAIN) . '</h1>';

		$this->addTabs();

		echo '<div class="tab-content">';

		$this->renderPreviewBox();

		echo '</div></div>';
	}

	private function renderPreviewBox(): void
	{
		echo '<div class="pro-preview preview-redirects">
			' . sprintf(__('%sRedirect manager is a Pro feature.%s%sGet Swift SEO Pro%s', WPSSEO_TEXT_DOMAIN), '<p>', '</p>', '<a href="' . WPSSEO_PLUGIN_URI . '" target="_blank" class="wpsseo-button hero">', '</a>') . '
		</div>';
	}

	private function addTabs(): void
	{
		$page = filter_input(INPUT_GET, 'page');

		$redirectsActive = $page === 'wpsseo-redirects';
		$redirects404Active = $page === 'wpsseo-redirects-404';
		$redirectsSettingsActive = $page === 'wpsseo-redirects-settings';

		echo '<h2 class="nav-tab-wrapper wpsseo-tabs">
			<a href="' . admin_url('/admin.php?page=wpsseo-redirects') . '" class="nav-tab' . ($redirectsActive ? ' nav-tab-active' : '') . '">' . __('Redirects', WPSSEO_TEXT_DOMAIN) . '</a>
			<a href="' . admin_url('/admin.php?page=wpsseo-redirects-404') . '" class="nav-tab' . ($redirects404Active ? ' nav-tab-active' : '') . '">' . __('404 errors', WPSSEO_TEXT_DOMAIN) . '</a>
			<a href="' . admin_url('/admin.php?page=wpsseo-redirects-settings') . '" class="nav-tab' . ($redirectsSettingsActive ? ' nav-tab-active' : '') . '">' . __('Settings', WPSSEO_TEXT_DOMAIN) . '</a>
		</h2>' . "\n";
	}

	private function formatUrl($url)
	{
		$urlParts = wp_parse_url($url);

		$path = strtolower(ltrim($urlParts['path'] ?? '', '/'));
		$query = $urlParts['query'] ?? '';

		if (!empty($query)) {
			$query = '?' . $query;
		}

		$uri = rtrim(rawurldecode($path . $query), '/');

		return !empty($uri) ? "/$uri" : '';
	}

	public function redirectToLowercase()
	{
		$uri = filter_input(INPUT_SERVER, 'REQUEST_URI');

		// If URI contains a dot, it's likely a file
		if (preg_match('/[\.]/', $uri)) {
			return;
		}

		// If URI contains no uppercase letters, skip it
		if (!preg_match('/[A-Z]/', $uri)) {
			return;
		}

		$formattedUri = $this->formatUrl($uri);
		if ($formattedUri === $uri) {
			return;
		}

		wp_redirect(home_url($formattedUri), 301, 'Swift SEO - Redirect Lowercase');
		exit;
	}
}
