<?php

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

class SwiftRestAPI
{
    private $requestedRoute;

    public function __construct()
    {
        $shouldRestrict = (bool) get_option('wpsseo_restrict_rest_api', true);

        if (!$shouldRestrict) {
            return;
        }

        $this->requestedRoute = isset($_SERVER['REQUEST_URI']) ? $_SERVER['REQUEST_URI'] : '';

        add_filter('rest_authentication_errors', [$this, 'restrictApiAccess']);
        add_filter('rest_prepare_attachment', [$this, 'disallowZipDownloads'], 10, 3);
    }

    public static function init()
    {
        return new self();
    }

    public function restrictApiAccess($result)
    {
        if (strpos($this->requestedRoute, '/wp/v2/media') !== false && ! current_user_can('edit_posts')) {
            return new WP_Error('rest_forbidden', __('Access to the media endpoint is restricted.'), array('status' => 403));
        }

        return $result;
    }

    public function disallowZipDownloads($response, $attachment, $request)
    {
        if (strpos($this->requestedRoute, '/wp/v2/media') !== false) {
            $isWooCommerce = strpos($attachment->guid, 'woocommerce_uploads') !== false;
            $isZipFile = strpos($attachment->post_mime_type, 'application/zip') !== false;

            if ($isWooCommerce || $isZipFile) {
                return new WP_REST_Response([], 200);
            }
        }

        return $response;
    }
}
