<?php

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

class SwiftSEO
{
    public function __construct()
    {
        add_action('init', [$this, 'loadTranslations'], 0);
        add_filter('plugin_action_links_' . plugin_basename(WPSSEO_FILE), [$this, 'actionLinks']);
        add_filter('plugin_row_meta', [$this, 'metaLinks'], 10, 2);

        // Initialize classes
        SwiftRestAPI::init();
        SwiftUpdater::init();
        SwiftRedirects::init();
        SwiftBlocks::init();
        SwiftCategories::init();
        SwiftSettings::init();
        SwiftRemoveGenesisSeo::init();
        SwiftWpMods::init();
        SwiftImages::init();
        SwiftMetaBoxes::init();
        SwiftAdminColumns::init();
        SwiftSeoHealth::init();
        SwiftTaxonomies::init();
        SwiftAuthor::init();
        SwiftRobots::init();
        SwiftPingService::init();
        SwiftMetaTags::init();
        SwiftSchema::init();
        SwiftSitemap::init();
        SwiftBreadcrumbs::init();
    }

    public static function init()
    {
        return new self();
    }

    public function loadTranslations()
    {
        load_plugin_textdomain(WPSSEO_TEXT_DOMAIN, false, basename(WPSSEO_DIR) . '/lang/');
    }

    public function actionLinks($links)
    {
        $links[] = '<a href="' . esc_url(admin_url('admin.php?page=swift-seo-settings')) . '">' . __('Settings', WPSSEO_TEXT_DOMAIN) . '</a>';
        $links[] = '<a href="https://swiftseo.app/products/plugins/swift-seo/" target="_blank" style="color: #524ed2; font-weight: 700">' . __('Get Pro Version', WPSSEO_TEXT_DOMAIN) . '</a>';

        return $links;
    }

    public function metaLinks($pluginMeta, $pluginFile)
    {
        if ($pluginFile === plugin_basename(WPSSEO_FILE)) {
            $linkAtts = 'target="_blank" style="color: #524ed2"';
            $pluginMeta = [
                sprintf(__('Version %s'), WPSSEO_VERSION),
                sprintf(__('By %s', WPSSEO_TEXT_DOMAIN), '<a href="https://swiftseo.app/" ' . $linkAtts . '>Swift SEO</a>'),
                '<a href="https://swiftseo.app/changelogs/swift-seo-lite/" ' . $linkAtts . '>' . __('Changelog', WPSSEO_TEXT_DOMAIN) . '</a>',
            ];
        }

        return $pluginMeta;
    }
}
