<?php

if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly
}

class SwiftContent
{
	// TODO: If changing this code, make sure to replicate in Swift FAQ Plugin + Swift themes
	public static function format($postContent, $postOverwrite = null)
	{
		if (!empty($postOverwrite)) {
			$postContent = get_the_content(null, false, $postOverwrite);
		}

		$postContent = str_replace(']]>', ']]&gt;', $postContent);
		$postContent = preg_replace('/<script\b[^<]*(?:(?!<\/script>)<[^<]*)*<\/script>/i', '', $postContent);
		$postContent = preg_replace('/<style\b[^<]*(?:(?!<\/style>)<[^<]*)*<\/style>/i', '', $postContent);

		if (function_exists('parse_blocks') && has_blocks($postContent)) {
			$postContent = self::parseBlocks($postContent);
		}

		$postContent = preg_replace('/<img[^>]+\>/i', ' ', $postContent);
		$postContent = wp_strip_all_tags(wpautop(strip_shortcodes($postContent)), true);

		return $postContent;
	}

	private static function parseBlocks($content)
	{
		$blocks = parse_blocks($content);
		$parsedContent = '';

		foreach ($blocks as $block) {
			$parsedContent .= render_block($block);
		}

		return $parsedContent ?: $content;
	}

	public static function generateDocumentTitle($object, $type = 'post')
	{
		$companyName = get_option('wpsseo_company_name', get_option('blogname'));
		$appendToTitleTag = (bool) get_option('wpsseo_append_to_title_tag', true);
		$docTitle = $append = '';

		if ($appendToTitleTag) {
			$append = ' &bull; ' . $companyName;
		}

		if ($type === 'term') {
			$docTitle = get_term_meta($object->term_id, 'headline', true) ?: $object->name;
			$taxonomy = get_taxonomy($object->taxonomy);
			if ($taxonomy) {
				$docTitle = $taxonomy->labels->singular_name . ': ' . $docTitle;
			}
		} elseif ($type === 'author') {
			$docTitle = get_user_meta($object->ID, 'headline', true) ?: ($object->display_name ?? $object->user_login);
		} elseif ($type === 'post') {
			$docTitle = $object->post_title;

			if (defined('WPSGLS_VERSION') && $object->post_type === 'wpsseo_term') {
				$termTemplate = get_option('wpsgls_term_template');
				if ($termTemplate) {
					$docTitle = str_replace('[term]', $docTitle, $termTemplate);
				}

				$customHeadline = get_post_meta($object->ID, 'custom_headline', true);
				if ($customHeadline) {
					$docTitle = $customHeadline;
				}
			}
		}

		$totalLength = mb_strlen($docTitle . $append);
		if ($docTitle && $totalLength <= WPSSEO_REC_TITLE_MAX_LENGTH && strpos($docTitle, $companyName) === false) {
			$docTitle .= $append;
		}

		return trim($docTitle);
	}

	public static function generateMetaDescription($object, $type = 'post')
	{
		if (! is_object($object) && ! is_numeric($object)) {
			return '';
		}

		$objectId = is_numeric($object) ? $object : ( $type === 'term' ? $object->term_id : $object->ID );
		$content = '';

		// Compatibility with Page Builders
		if (! empty($objectId)) {
			$oxygenContent = SwiftOxygen::getContent($objectId, $type);
			if (!empty($oxygenContent)) {
				$content = $oxygenContent;
			}
		}
		// End compatibility with Page Builders

		if (empty($content)) {
			if ($type === 'term') {
				$content = get_term_meta($objectId, 'intro_text', true) ?: get_term_meta($objectId, 'description', true);
			} elseif ($type === 'author') {
				$content = get_user_meta($objectId, 'intro_text', true) ?: get_the_author_meta('description', $objectId);
			} elseif ($type === 'post') {
				$object = is_numeric($object) ? get_post($object) : $object;
				$content = $object->post_content;
			}
		}

		$rawContent = self::format($content);
		$generatedDescription = self::trimDescription($rawContent);

		return trim($generatedDescription);
	}

	public static function trimDescription($str, $minLength = null, $maxLength = null)
	{
		$str = preg_replace('/\s+/i', ' ', $str);
		$strLength = strlen($str);
		$minLength = $minLength ?? WPSSEO_REC_DESC_MIN_LENGTH;
		$maxLength = $maxLength ?? WPSSEO_REC_DESC_MAX_LENGTH;

		if ($strLength <= $maxLength) {
			return $str;
		}

		return trim(mb_substr($str, 0, $maxLength - 3)) . '...';
	}

	public static function trimDescriptionBySentences($str, $minLength = null, $maxLength = null)
	{
		$str = preg_replace('/\s+/i', ' ', $str);
		$strLength = strlen($str);
		$minLength = $minLength ?? WPSSEO_REC_DESC_MIN_LENGTH;
		$maxLength = $maxLength ?? WPSSEO_REC_DESC_MAX_LENGTH;

		if ($strLength <= $maxLength) {
			return $str;
		}

		$strParts = array_map('trim', explode('.', $str));
		$returnStr = '';

		foreach ($strParts as $part) {
			if (empty($returnStr)) {
				$returnStr = $part;
				continue;
			}

			$currentLength = mb_strlen($returnStr);
			$partLength = mb_strlen($part);
			if ($currentLength >= $minLength) {
				if ($currentLength >= $maxLength || (!empty($part) && ($currentLength + $partLength + 2) > $maxLength)) {
					break;
				}
			}

			if (empty($part)) {
				$returnStr .= '.';
				continue;
			}

			$returnStr .= '. ' . $part;
		}

		return $returnStr;
	}

	public static function trimDescriptionByWords($str, $minLength = null, $maxLength = null)
	{
		$str = preg_replace('/\s+/i', ' ', $str);
		$strLength = strlen($str);
		$minLength = $minLength ?? WPSSEO_REC_DESC_MIN_LENGTH;
		$maxLength = $maxLength ?? WPSSEO_REC_DESC_MAX_LENGTH;

		if ($strLength <= $maxLength) {
			return $str;
		}

		$strParts = explode(' ', $str);
		$returnStr = '';

		foreach ($strParts as $part) {
			if (empty($returnStr)) {
				$returnStr = $part;
				continue;
			}

			$currentLength = mb_strlen($returnStr);
			$partLength = mb_strlen($part);
			if ($currentLength >= $minLength) {
				if ($currentLength >= $maxLength || (!empty($part) && ($currentLength + $partLength + 1) > $maxLength)) {
					break;
				}
			}

			$returnStr .= ' ' . $part;
		}

		return $returnStr;
	}
}
