<?php

if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly
}

class SwiftDomain
{
	public static function currentUrl($keepQueryString = true)
	{
		$uri = filter_input(INPUT_SERVER, 'REQUEST_URI');
		$queryString = filter_input(INPUT_SERVER, 'QUERY_STRING');
		$permalinkStructure = get_option('permalink_structure', '/');

		if ($queryString) {
			$uri = explode('?', $uri)[0];
		}

		$uri = htmlspecialchars($uri, ENT_QUOTES);

		if (substr($permalinkStructure, -1) === '/') {
			$uri = trailingslashit($uri);
		}

		if ($keepQueryString && $queryString) {
			$uri .= '?' . $queryString;
		}

		return home_url($uri);
	}

	public static function isPaginated()
	{
		global $wp_query;

		return (bool) ($wp_query->max_num_pages > 1);
	}

	public static function isFirstPage()
	{
		return !is_paged();
	}

	public static function isLastPage()
	{
		if (is_paged()) {
			global $wp_query;

			return get_query_var('paged') === $wp_query->max_num_pages;
		}

		return false;
	}

	public static function maxPages()
	{
		global $wp_query;

		return intval($wp_query->max_num_pages);
	}
}
