<?php

if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly
}

class SwiftUtilities
{
	private static function getPostsRecursive($parentId, $children, &$return, $level = 0)
	{
		$level++;
		$padding = str_repeat('&nbsp;', $level * 3);

		if (!empty($children[$parentId])) {
			foreach ($children[$parentId] as $child) {
				$return[$child->ID] = $padding . $child->post_title;
				self::getPostsRecursive($child->ID, $children, $return, $level);
			}
		}
	}

	public static function dropdownPages($args = [])
	{
		$defaults = [
			'posts_per_page'    => -1,
			'offset'            => 0,
			'category'          => '',
			'orderby'           => 'menu_order',
			'order'             => 'DESC',
			'include'           => '',
			'exclude'           => '',
			'meta_key'          => '',
			'meta_value'        => '',
			'post_type'         => 'page',
			'post_status'       => 'publish',
			'suppress_filters'  => false,
		];

		$posts = get_posts(array_merge($defaults, $args));
		$parents = [];
		$children = [];

		foreach ($posts as $post) {
			if ($post->post_parent == 0) {
				$parents[] = $post;
			} else {
				$children[$post->post_parent][] = $post;
			}
		}

		$return = [];
		foreach ($parents as $parent) {
			$return[$parent->ID] = $parent->post_title;
			self::getPostsRecursive($parent->ID, $children, $return);
		}

		return $return;
	}

	public static function countriesByContinent()
	{
		return [
			__("Africa", WPSSEO_TEXT_DOMAIN) => [
				"DZ" => __("Algeria", WPSSEO_TEXT_DOMAIN),
				"AO" => __("Angola", WPSSEO_TEXT_DOMAIN),
				"BJ" => __("Benin", WPSSEO_TEXT_DOMAIN),
				"BW" => __("Botswana", WPSSEO_TEXT_DOMAIN),
				"BF" => __("Burkina Faso", WPSSEO_TEXT_DOMAIN),
				"BI" => __("Burundi", WPSSEO_TEXT_DOMAIN),
				"CM" => __("Cameroon", WPSSEO_TEXT_DOMAIN),
				"CV" => __("Cape Verde", WPSSEO_TEXT_DOMAIN),
				"CF" => __("Central African Republic", WPSSEO_TEXT_DOMAIN),
				"TD" => __("Chad", WPSSEO_TEXT_DOMAIN),
				"KM" => __("Comoros", WPSSEO_TEXT_DOMAIN),
				"CG" => __("Congo - Brazzaville", WPSSEO_TEXT_DOMAIN),
				"CD" => __("Congo - Kinshasa", WPSSEO_TEXT_DOMAIN),
				"DJ" => __("Djibouti", WPSSEO_TEXT_DOMAIN),
				"EG" => __("Egypt", WPSSEO_TEXT_DOMAIN),
				"CI" => __("Ivory Coast", WPSSEO_TEXT_DOMAIN),
				"GQ" => __("Equatorial Guinea", WPSSEO_TEXT_DOMAIN),
				"ER" => __("Eritrea", WPSSEO_TEXT_DOMAIN),
				"ET" => __("Ethiopia", WPSSEO_TEXT_DOMAIN),
				"GA" => __("Gabon", WPSSEO_TEXT_DOMAIN),
				"GM" => __("Gambia", WPSSEO_TEXT_DOMAIN),
				"GH" => __("Ghana", WPSSEO_TEXT_DOMAIN),
				"GN" => __("Guinea", WPSSEO_TEXT_DOMAIN),
				"GW" => __("Guinea-Bissau", WPSSEO_TEXT_DOMAIN),
				"KE" => __("Kenya", WPSSEO_TEXT_DOMAIN),
				"LS" => __("Lesotho", WPSSEO_TEXT_DOMAIN),
				"LR" => __("Liberia", WPSSEO_TEXT_DOMAIN),
				"LY" => __("Libya", WPSSEO_TEXT_DOMAIN),
				"MG" => __("Madagascar", WPSSEO_TEXT_DOMAIN),
				"MW" => __("Malawi", WPSSEO_TEXT_DOMAIN),
				"ML" => __("Mali", WPSSEO_TEXT_DOMAIN),
				"MA" => __("Morocco", WPSSEO_TEXT_DOMAIN),
				"MR" => __("Mauritania", WPSSEO_TEXT_DOMAIN),
				"MU" => __("Mauritius", WPSSEO_TEXT_DOMAIN),
				"MZ" => __("Mozambique", WPSSEO_TEXT_DOMAIN),
				"NA" => __("Namibia", WPSSEO_TEXT_DOMAIN),
				"NE" => __("Niger", WPSSEO_TEXT_DOMAIN),
				"NG" => __("Nigeria", WPSSEO_TEXT_DOMAIN),
				"RW" => __("Rwanda", WPSSEO_TEXT_DOMAIN),
				"ST" => __("São Tomé and Príncipe", WPSSEO_TEXT_DOMAIN),
				"SN" => __("Senegal", WPSSEO_TEXT_DOMAIN),
				"SC" => __("Seychelles", WPSSEO_TEXT_DOMAIN),
				"SL" => __("Sierra Leone", WPSSEO_TEXT_DOMAIN),
				"SO" => __("Somalia", WPSSEO_TEXT_DOMAIN),
				"SD" => __("Sudan", WPSSEO_TEXT_DOMAIN),
				"ZA" => __("South Africa", WPSSEO_TEXT_DOMAIN),
				"SS" => __("South Sudan", WPSSEO_TEXT_DOMAIN),
				"SZ" => __("Swaziland", WPSSEO_TEXT_DOMAIN),
				"TZ" => __("Tanzania", WPSSEO_TEXT_DOMAIN),
				"TG" => __("Togo", WPSSEO_TEXT_DOMAIN),
				"TN" => __("Tunisia", WPSSEO_TEXT_DOMAIN),
				"UG" => __("Uganda", WPSSEO_TEXT_DOMAIN),
				"ZM" => __("Zambia", WPSSEO_TEXT_DOMAIN),
				"ZW" => __("Zimbabwe", WPSSEO_TEXT_DOMAIN)
			],
			__("Asia", WPSSEO_TEXT_DOMAIN) => [
				"AF" => __("Afghanistan", WPSSEO_TEXT_DOMAIN),
				"AM" => __("Armenia", WPSSEO_TEXT_DOMAIN),
				"AZ" => __("Azerbaijan", WPSSEO_TEXT_DOMAIN),
				"BH" => __("Bahrain", WPSSEO_TEXT_DOMAIN),
				"BD" => __("Bangladesh", WPSSEO_TEXT_DOMAIN),
				"BT" => __("Bhutan", WPSSEO_TEXT_DOMAIN),
				"BN" => __("Brunei", WPSSEO_TEXT_DOMAIN),
				"MM" => __("Burma", WPSSEO_TEXT_DOMAIN),
				"KH" => __("Cambodia", WPSSEO_TEXT_DOMAIN),
				"AE" => __("United Arab Emirates", WPSSEO_TEXT_DOMAIN),
				"PH" => __("Philippines", WPSSEO_TEXT_DOMAIN),
				"GE" => __("Georgia", WPSSEO_TEXT_DOMAIN),
				"IN" => __("India", WPSSEO_TEXT_DOMAIN),
				"ID" => __("Indonesia", WPSSEO_TEXT_DOMAIN),
				"IQ" => __("Iraq", WPSSEO_TEXT_DOMAIN),
				"IR" => __("Iran", WPSSEO_TEXT_DOMAIN),
				"IL" => __("Israel", WPSSEO_TEXT_DOMAIN),
				"JP" => __("Japan", WPSSEO_TEXT_DOMAIN),
				"JO" => __("Jordan", WPSSEO_TEXT_DOMAIN),
				"KZ" => __("Kazakhstan", WPSSEO_TEXT_DOMAIN),
				"CN" => __("China", WPSSEO_TEXT_DOMAIN),
				"KG" => __("Kyrgyzstan", WPSSEO_TEXT_DOMAIN),
				"KW" => __("Kuwait", WPSSEO_TEXT_DOMAIN),
				"LA" => __("Laos", WPSSEO_TEXT_DOMAIN),
				"LB" => __("Lebanon", WPSSEO_TEXT_DOMAIN),
				"MY" => __("Malaysia", WPSSEO_TEXT_DOMAIN),
				"MV" => __("Maldives", WPSSEO_TEXT_DOMAIN),
				"MN" => __("Mongolia", WPSSEO_TEXT_DOMAIN),
				"NP" => __("Nepal", WPSSEO_TEXT_DOMAIN),
				"KP" => __("North Korea", WPSSEO_TEXT_DOMAIN),
				"OM" => __("Oman", WPSSEO_TEXT_DOMAIN),
				"PK" => __("Pakistan", WPSSEO_TEXT_DOMAIN),
				"PS" => __("Palestine", WPSSEO_TEXT_DOMAIN),
				"QA" => __("Qatar", WPSSEO_TEXT_DOMAIN),
				"RU" => __("Russia", WPSSEO_TEXT_DOMAIN),
				"SA" => __("Saudi Arabia", WPSSEO_TEXT_DOMAIN),
				"SG" => __("Singapore", WPSSEO_TEXT_DOMAIN),
				"LK" => __("Sri Lanka", WPSSEO_TEXT_DOMAIN),
				"KR" => __("South Korea", WPSSEO_TEXT_DOMAIN),
				"SY" => __("Syria", WPSSEO_TEXT_DOMAIN),
				"TJ" => __("Tajikistan", WPSSEO_TEXT_DOMAIN),
				"TW" => __("Taiwan", WPSSEO_TEXT_DOMAIN),
				"TH" => __("Thailand", WPSSEO_TEXT_DOMAIN),
				"TL" => __("Timor-Leste", WPSSEO_TEXT_DOMAIN),
				"TM" => __("Turkmenistan", WPSSEO_TEXT_DOMAIN),
				"TR" => __("Turkey", WPSSEO_TEXT_DOMAIN),
				"UZ" => __("Uzbekistan", WPSSEO_TEXT_DOMAIN),
				"VN" => __("Vietnam", WPSSEO_TEXT_DOMAIN),
				"YE" => __("Yemen", WPSSEO_TEXT_DOMAIN)
			],
			__("Europe", WPSSEO_TEXT_DOMAIN) => [
				"AL" => __("Albania", WPSSEO_TEXT_DOMAIN),
				"AD" => __("Andorra", WPSSEO_TEXT_DOMAIN),
				"BE" => __("Belgium", WPSSEO_TEXT_DOMAIN),
				"BA" => __("Bosnia and Herzegovina", WPSSEO_TEXT_DOMAIN),
				"BG" => __("Bulgaria", WPSSEO_TEXT_DOMAIN),
				"CY" => __("Cyprus", WPSSEO_TEXT_DOMAIN),
				"DK" => __("Denmark", WPSSEO_TEXT_DOMAIN),
				"EE" => __("Estonia", WPSSEO_TEXT_DOMAIN),
				"FI" => __("Finland", WPSSEO_TEXT_DOMAIN),
				"FR" => __("France", WPSSEO_TEXT_DOMAIN),
				"GR" => __("Greece", WPSSEO_TEXT_DOMAIN),
				"NL" => __("Netherlands", WPSSEO_TEXT_DOMAIN),
				"BY" => __("Belarus", WPSSEO_TEXT_DOMAIN),
				"IE" => __("Ireland", WPSSEO_TEXT_DOMAIN),
				"IS" => __("Iceland", WPSSEO_TEXT_DOMAIN),
				"IT" => __("Italy", WPSSEO_TEXT_DOMAIN),
				"XK" => __("Kosovo", WPSSEO_TEXT_DOMAIN),
				"HR" => __("Croatia", WPSSEO_TEXT_DOMAIN),
				"LV" => __("Latvia", WPSSEO_TEXT_DOMAIN),
				"LI" => __("Liechtenstein", WPSSEO_TEXT_DOMAIN),
				"LT" => __("Lithuania", WPSSEO_TEXT_DOMAIN),
				"LU" => __("Luxembourg", WPSSEO_TEXT_DOMAIN),
				"MT" => __("Malta", WPSSEO_TEXT_DOMAIN),
				"MD" => __("Moldova", WPSSEO_TEXT_DOMAIN),
				"MC" => __("Monaco", WPSSEO_TEXT_DOMAIN),
				"ME" => __("Montenegro", WPSSEO_TEXT_DOMAIN),
				"MK" => __("North Macedonia", WPSSEO_TEXT_DOMAIN),
				"NO" => __("Norway", WPSSEO_TEXT_DOMAIN),
				"PL" => __("Poland", WPSSEO_TEXT_DOMAIN),
				"PT" => __("Portugal", WPSSEO_TEXT_DOMAIN),
				"RO" => __("Romania", WPSSEO_TEXT_DOMAIN),
				"RU" => __("Russia", WPSSEO_TEXT_DOMAIN),
				"SM" => __("San Marino", WPSSEO_TEXT_DOMAIN),
				"CH" => __("Switzerland", WPSSEO_TEXT_DOMAIN),
				"RS" => __("Serbia", WPSSEO_TEXT_DOMAIN),
				"SK" => __("Slovakia", WPSSEO_TEXT_DOMAIN),
				"SI" => __("Slovenia", WPSSEO_TEXT_DOMAIN),
				"ES" => __("Spain", WPSSEO_TEXT_DOMAIN),
				"GB" => __("United Kingdom", WPSSEO_TEXT_DOMAIN),
				"SE" => __("Sweden", WPSSEO_TEXT_DOMAIN),
				"CZ" => __("Czech Republic", WPSSEO_TEXT_DOMAIN),
				"DE" => __("Germany", WPSSEO_TEXT_DOMAIN),
				"UA" => __("Ukraine", WPSSEO_TEXT_DOMAIN),
				"HU" => __("Hungary", WPSSEO_TEXT_DOMAIN),
				"VA" => __("Vatican City", WPSSEO_TEXT_DOMAIN),
				"AT" => __("Austria", WPSSEO_TEXT_DOMAIN)
			],
			__("North America", WPSSEO_TEXT_DOMAIN) => [
				"AG" => __("Antigua and Barbuda", WPSSEO_TEXT_DOMAIN),
				"BS" => __("Bahamas", WPSSEO_TEXT_DOMAIN),
				"BB" => __("Barbados", WPSSEO_TEXT_DOMAIN),
				"BZ" => __("Belize", WPSSEO_TEXT_DOMAIN),
				"CA" => __("Canada", WPSSEO_TEXT_DOMAIN),
				"CR" => __("Costa Rica", WPSSEO_TEXT_DOMAIN),
				"CU" => __("Cuba", WPSSEO_TEXT_DOMAIN),
				"DM" => __("Dominica", WPSSEO_TEXT_DOMAIN),
				"DO" => __("Dominican Republic", WPSSEO_TEXT_DOMAIN),
				"SV" => __("El Salvador", WPSSEO_TEXT_DOMAIN),
				"GD" => __("Grenada", WPSSEO_TEXT_DOMAIN),
				"GT" => __("Guatemala", WPSSEO_TEXT_DOMAIN),
				"HT" => __("Haiti", WPSSEO_TEXT_DOMAIN),
				"HN" => __("Honduras", WPSSEO_TEXT_DOMAIN),
				"JM" => __("Jamaica", WPSSEO_TEXT_DOMAIN),
				"MX" => __("Mexico", WPSSEO_TEXT_DOMAIN),
				"NI" => __("Nicaragua", WPSSEO_TEXT_DOMAIN),
				"PA" => __("Panama", WPSSEO_TEXT_DOMAIN),
				"KN" => __("Saint Kitts and Nevis", WPSSEO_TEXT_DOMAIN),
				"LC" => __("Saint Lucia", WPSSEO_TEXT_DOMAIN),
				"VC" => __("Saint Vincent and the Grenadines", WPSSEO_TEXT_DOMAIN),
				"TT" => __("Trinidad and Tobago", WPSSEO_TEXT_DOMAIN),
				"US" => __("United States", WPSSEO_TEXT_DOMAIN)
			],
			__("South America", WPSSEO_TEXT_DOMAIN) => [
				"AR" => __("Argentina", WPSSEO_TEXT_DOMAIN),
				"BO" => __("Bolivia", WPSSEO_TEXT_DOMAIN),
				"BR" => __("Brazil", WPSSEO_TEXT_DOMAIN),
				"CL" => __("Chile", WPSSEO_TEXT_DOMAIN),
				"CO" => __("Colombia", WPSSEO_TEXT_DOMAIN),
				"EC" => __("Ecuador", WPSSEO_TEXT_DOMAIN),
				"GY" => __("Guyana", WPSSEO_TEXT_DOMAIN),
				"PY" => __("Paraguay", WPSSEO_TEXT_DOMAIN),
				"PE" => __("Peru", WPSSEO_TEXT_DOMAIN),
				"SR" => __("Suriname", WPSSEO_TEXT_DOMAIN),
				"UY" => __("Uruguay", WPSSEO_TEXT_DOMAIN),
				"VE" => __("Venezuela", WPSSEO_TEXT_DOMAIN)
			],
			__("Oceania", WPSSEO_TEXT_DOMAIN) => [
				"AU" => __("Australia", WPSSEO_TEXT_DOMAIN),
				"FJ" => __("Fiji", WPSSEO_TEXT_DOMAIN),
				"KI" => __("Kiribati", WPSSEO_TEXT_DOMAIN),
				"MH" => __("Marshall Islands", WPSSEO_TEXT_DOMAIN),
				"FM" => __("Micronesia", WPSSEO_TEXT_DOMAIN),
				"NR" => __("Nauru", WPSSEO_TEXT_DOMAIN),
				"NZ" => __("New Zealand", WPSSEO_TEXT_DOMAIN),
				"PW" => __("Palau", WPSSEO_TEXT_DOMAIN),
				"PG" => __("Papua New Guinea", WPSSEO_TEXT_DOMAIN),
				"WS" => __("Samoa", WPSSEO_TEXT_DOMAIN),
				"SB" => __("Solomon Islands", WPSSEO_TEXT_DOMAIN),
				"TO" => __("Tonga", WPSSEO_TEXT_DOMAIN),
				"TV" => __("Tuvalu", WPSSEO_TEXT_DOMAIN),
				"VU" => __("Vanuatu", WPSSEO_TEXT_DOMAIN)
			]
		];
	}

	public static function getCountryName($code)
	{
		$countries = self::countriesByContinent();
		foreach ($countries as $continent) {
			foreach ($continent as $countryCode => $countryName) {
				if ($countryCode === $code) {
					return $countryName;
				}
			}
		}

		return $code;
	}

	public static function getUrlContent($url)
	{
		defined('WP_ENVIRONMENT_TYPE') or define('WP_ENVIRONMENT_TYPE', get_option('swift_theme_environment', 'development'));
		$isLocal = WP_ENVIRONMENT_TYPE !== 'production';

		$context = stream_context_create([
			"ssl" => [
				"verify_peer" => !$isLocal,
				"verify_peer_name" => !$isLocal,
			],
		]);

		return file_get_contents($url, false, $context);
	}

	public static function isFeed()
	{
		$isFeed = function_exists('is_feed') ? is_feed() : false;

		if (isset($_GET['feed']) && $_GET['feed'] !== '0' && $_GET['feed'] !== 'false') {
			$isFeed = true;
		}

		if (!$isFeed) {
			$uriBase = basename(filter_input(INPUT_SERVER, 'REQUEST_URI'));

			if ($uriBase === 'feed') {
				$queriedObject = get_queried_object();

				if (!$queriedObject) {
					$isFeed = true;
				}
			}
		}

		return $isFeed;
	}
}
