<?php

if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly
}

function swiftSeoGetVersionNumber()
{
	if (!is_admin()) {
		return '';
	}

	$docComment = array_reduce(
		token_get_all(file_get_contents(WPSSEO_FILE)),
		function ($carry, $entry) {
			return $carry ?: ($entry[0] === T_DOC_COMMENT ? $entry[1] : null);
		}
	);

	preg_match('/^ \* Version:\s*(.*)$/mi', $docComment, $matches);

	return trim($matches[1] ?? '');
}

// Static Constants
defined('WPSSEO_UPDATE_URL') or define('WPSSEO_UPDATE_URL', 'https://swiftseo.app/wp-json/plugins/v1/check-update?p=swift-seo-lite_6730aa2e440ad4.35793431');
defined('WPSSEO_TEXT_DOMAIN') or define('WPSSEO_TEXT_DOMAIN', 'swift-seo-lite');
defined('WPSSEO_PLUGIN_URI') or define('WPSSEO_PLUGIN_URI', 'https://swiftseo.app/products/plugins/swift-seo/');
defined('WPSSEO_IS_PUBLIC') or define('WPSSEO_IS_PUBLIC', (bool) get_option('blog_public', false));
defined('WPSSEO_IS_ADMIN') or define('WPSSEO_IS_ADMIN', (bool) is_admin());
defined('WPSSEO_SLUG') or define('WPSSEO_SLUG', plugin_basename(WPSSEO_DIR));
defined('WPSSEO_VERSION') or define('WPSSEO_VERSION', swiftSeoGetVersionNumber());

// Number of characters, suggestion same as Screaming Frog
defined('WPSSEO_REC_TITLE_MIN_LENGTH') or define('WPSSEO_REC_TITLE_MIN_LENGTH', 30);
defined('WPSSEO_REC_TITLE_MAX_LENGTH') or define('WPSSEO_REC_TITLE_MAX_LENGTH', 60);
defined('WPSSEO_REC_DESC_MIN_LENGTH') or define('WPSSEO_REC_DESC_MIN_LENGTH', 70);

// Number of characters, suggestion from Google Gemini as a safe limit. If updating this, update in Swift_Theme_Search too
defined('WPSSEO_REC_DESC_MAX_LENGTH') or define('WPSSEO_REC_DESC_MAX_LENGTH', 160);

// Character treshold that should trigger a warning instead of an error
defined('WPSSEO_BAD_TITLE_MIN_LENGTH') or define('WPSSEO_BAD_TITLE_MIN_LENGTH', WPSSEO_REC_TITLE_MIN_LENGTH - 10);
defined('WPSSEO_BAD_TITLE_MAX_LENGTH') or define('WPSSEO_BAD_TITLE_MAX_LENGTH', WPSSEO_REC_TITLE_MAX_LENGTH + 10);
defined('WPSSEO_BAD_DESC_MIN_LENGTH') or define('WPSSEO_BAD_DESC_MIN_LENGTH', WPSSEO_REC_DESC_MIN_LENGTH - 10);
defined('WPSSEO_BAD_DESC_MAX_LENGTH') or define('WPSSEO_BAD_DESC_MAX_LENGTH', WPSSEO_REC_DESC_MAX_LENGTH + 10);

// Number of words from personal experience
defined('WPSSEO_REC_CONTENT_MIN_LENGTH') or define('WPSSEO_REC_CONTENT_MIN_LENGTH', 240);
defined('WPSSEO_CONTENT_MIN_LENGTH') or define('WPSSEO_CONTENT_MIN_LENGTH', ((int) (WPSSEO_REC_CONTENT_MIN_LENGTH / 2)));
defined('WPSSEO_REC_PRODUCT_MIN_LENGTH') or define('WPSSEO_REC_PRODUCT_MIN_LENGTH', ((int) (WPSSEO_REC_CONTENT_MIN_LENGTH / 1.5)));
defined('WPSSEO_PRODUCT_MIN_LENGTH') or define('WPSSEO_PRODUCT_MIN_LENGTH', ((int) (WPSSEO_REC_PRODUCT_MIN_LENGTH / 2)));

// WooCommerce Constant
add_action('plugins_loaded', function () {
	defined('WPSSEO_IS_WOOCOMMERCE') or define('WPSSEO_IS_WOOCOMMERCE', (bool) class_exists('WooCommerce'));
});

// Autoload Classes
$classes = glob(__DIR__ . '/classes/*/*.php', GLOB_NOSORT);
if (!empty($classes)) {
	foreach ($classes as $class) {
		include_once($class);
	}
}

// Dynamic Constants
defined('WPSSEO_CURRENT_URL') or define('WPSSEO_CURRENT_URL', SwiftDomain::currentUrl());
